﻿Ext.define('App.Control.Kivii.Finances.InvoiceApplyDetail.Form', {
    extend: 'System.Control.EntityForm',
    xtype: 'App.Control.Kivii.Finances.InvoiceApplyDetail.Form',
    entityType: 'Kivii.Finances.Entities.InvoiceApplyDetail',
    layout: {
        type: 'responsivecolumn',
        states: {
            small: 1000,
            large: 0
        }
    },
    viewModel: {
        data: {
        	isAdd:false,
            entity: {
            },
            currentAmount:0
        },
        formulas: {
            calculating:function(get) {
                let _amount = get('entity.Amount');
                let _quantity = get('entity.Quantity');
                let _taxRate = get('entity.TaxRate');
                let _amountUntaxed = (parseFloat(_amount)/(1+parseFloat(_taxRate))).toFixed(2);
                let _amountTax = (parseFloat(_amount)-parseFloat(_amountUntaxed)).toFixed(2);
                let _quantityUnitPrice = (parseFloat(_amount)/parseFloat(_quantity)).toFixed(2);
                let _quantityUnitPriceUntaxed = (parseFloat(_amountUntaxed)/parseFloat(_quantity)).toFixed(2);
                this.set('entity.AmountUntaxed',_amountUntaxed);
                this.set('entity.AmountTax',_amountTax);
                this.set('entity.QuantityUnitPrice',_quantityUnitPrice);
                this.set('entity.QuantityUnitPriceUntaxed',_quantityUnitPriceUntaxed);
                return _amount;
            }
        }
    },
    autoScroll: true,
    defaults: {
        labelWidth: 80,
        xtype: 'textfield',
        layout: 'responsivecolumn',
        margin: '0 20 10 0'
    },
    tbar: [{
        margin: '0 0 -9 3',
        xtype: 'displayfield',
        bind: {
            value: '已有明细总额：{currentAmount},当前明细金额：{entity.Amount}'
        },
        fieldStyle: {
            fontSize: '20px'
        }

    }, '->', {
        text: '保存',
        iconCls: 'x-fa fa-link',
        iconAlign: 'left',
        handler: '_onSaveEntity',
        bind: {
            disabled: '{!formIsValid}'
        }
    }],
    items: [{
    	xtype: 'displayfield',
        bind: {
            value: '组别是用于当前申请多张发票时,不同组别会分别开具到对应组别的发票上'
        },
        fieldStyle: {
            fontSize: '20px'
        }
    },{
        xtype: 'categoryField',
        fieldLabel: '组&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;别',
        responsiveCls: 'big-100 small-100',
        allowBlank: false,
        bind: '{entity.GoodsId}',
        internalCode: 'GoodsId',
        entityType: 'Kivii.Finances.Entities.InvoiceApplyDetail'
    }, {
        xtype: 'categoryField',
        fieldLabel: '货品名称',
        responsiveCls: 'big-100 small-100',
        allowBlank: false,
        bind: '{entity.GoodsFullName}',
        internalCode: 'GoodsFullName',
        entityType: 'Kivii.Finances.Entities.InvoiceApplyDetail'
    // },{
    //     xtype: 'textfield',
    //     fieldLabel: '货品名称',
    //     responsiveCls: 'big-100 small-100',
    //     allowBlank: false,
    //     readOnly:true,
    //     bind: '{entity.GoodsFullName}'
    },{
        xtype: 'textfield',
        fieldLabel: '货品规格',
        responsiveCls: 'big-100 small-100',
        bind: '{entity.GoodsSpecifications}'
    },{
    	xtype: 'numberfield',
    	fieldLabel: '金额(含税)',
        hideTrigger: true,
        allowBlank: false,
    	responsiveCls: 'big-60 small-100',
    	bind: '{entity.Amount}'
    },{
        xtype: 'categoryField',
        fieldLabel: '税&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;率',
        responsiveCls: 'big-40 small-100',
        allowBlank: false,
        bind: '{entity.TaxRate}',
        internalCode: 'TaxRate',
        entityType: 'Kivii.Finances.Entities.InvoiceApplyDetail'
    },{
        xtype: 'numberfield',
        fieldLabel: '数&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;量',
        hideTrigger: true,
        allowBlank: false,
        responsiveCls: 'big-60 small-100',
        bind: '{entity.Quantity}'
    },{
        xtype: 'textfield',
        fieldLabel: '数量单位',
        allowBlank: false,
        responsiveCls: 'big-40 small-100',
        bind: '{entity.QuantityUnit}'
    }, {
    	xtype: 'numberfield',
    	fieldLabel: '单价(含税)',
    	readOnly:true,
        hideTrigger: true,
    	responsiveCls: 'big-60 small-100',
    	bind: '{entity.QuantityUnitPrice}'
    },{
    	xtype: 'numberfield',
    	fieldLabel: '单价(不含税)',
    	readOnly:true,
        hideTrigger: true,
    	responsiveCls: 'big-40 small-100',
    	bind: '{entity.QuantityUnitPriceUntaxed}'
    },{
    	xtype: 'numberfield',
    	fieldLabel: '金额(不含税)',
    	readOnly:true,
        hideTrigger: true,
    	responsiveCls: 'big-60 small-100',
    	bind: '{entity.AmountUntaxed}'
    },{
    	xtype: 'numberfield',
    	fieldLabel: '税额',
    	readOnly:true,
        hideTrigger: true,
    	responsiveCls: 'big-40 small-100',
    	bind: '{entity.AmountTax}'
    },{
        xtype: 'textarea',
        fieldLabel: '备注',
        responsiveCls: 'big-100 small-100',
        readOnly: false,
        bind: {
            value: '{entity.MatchText}'
        }
    }],
    setOwner: function(_entity,_records,_isAdd) {
        let _view = this;
        let _vm = _view.getViewModel();
        if(_isAdd===null||_isAdd===undefined)_isAdd=false;
        _vm.set('isAdd',_isAdd);
        _vm.set('entity', _entity);
        let _currentAmount=0;
        for (let _i = 0; _i < _records.length; _i++) {
        	let _record=_records[_i].data;
        	_currentAmount+=_record.Amount;
        }
        _vm.set('currentAmount',_currentAmount.toFixed(2));
    },
    controller: {
        _onSaveEntity: function(_ctrl) {
            let _controller = this,
                _view = _controller.getView();
            let _vm = _controller.getViewModel();
            if(!_vm.data.isAdd)_view.fireEvent('entityUpdated', _view, _vm.data.entity);
            else _view.fireEvent('entityAdd', _view, _vm.data.entity);
        }
    }
});