﻿Ext.define('App.Control.Kivii.Finances.Settlement.Chart.Type', {
    extend: 'Ext.Panel',
    xtype: 'App.Control.Kivii.Finances.Settlement.Chart.Type',
    requires: ['Package.charts', 'System.Control.ComboSelector'],
    autoScroll: true,
    dockedItems: [{
        xtype: 'toolbar',
        dock: 'top',
        overflowHandler: 'scroller',
        items: [{
                // margin: '0 3 -10 3',
                xtype: 'displayfield',
                value: '结算类型统计',
                fieldStyle: {
                    fontSize: '22px'
                }
            }, '->', {
                xtype: 'comboSelector',
                dataSource: '/Restful/Kivii.Organizations.Entities.Organization/Query.json',
                reference: 'depart',
                responsiveCls: 'big-100 small-100',
                keyField: 'Kvid',
                valueField: 'FullName',
                key: KiviiContext.CurrentMember.DepartmentKvid,
                value: KiviiContext.CurrentMember.DepartmentName,
                editable: false,
                width: 300,
                allowBlank: true,
                listeners: {
                    select: '_onSelect'
                }
            },{
                xtype: 'datefield',
                fieldLabel: '时间范围',
                format: 'Y-m-d',
                labelWidth: 60,
                width: 220,
                reference: 'beginTime',
                editable: false,
                value: new Date(new Date().getFullYear(), new Date().getMonth(), 1),
                listeners: {
                    select: '_onSelectMonth'
                }
            },
            {
                xtype: 'datefield',
                // fieldLabel: '结束',
                format: 'Y-m-d',
                // labelWidth: 30,
                width: 130,
                reference: 'endTime',
                editable: false,
                value: new Date(new Date().getFullYear(), new Date().getMonth(), new Date().getDate() + 1),
                listeners: {
                    select: '_onSelectMonth'
                }
            }
        ]
    }],
    items: [{
        xtype: 'polar',
        reference: 'chart',
        downloadServerUrl: '//svg.sencha.io',
        innerPadding: 40,
        // width: '100%',
        height: 400,
        store: {
            fields: ['Summary', 'Amount'],
            data: []
            // data: [
            //     { Summary: 'Service', Amount: 83000 },
            //     { Summary: 'Express', Amount: 17000 },
            //     { Summary: 'Report', Amount: 179000 }
            // ]
        },
        theme: 'Muted', //'Muted',
        interactions: ['itemhighlight', 'rotatePie3d'],
        legend: {
            type: 'sprite',
            docked: 'bottom'
        },
        series: [{
            type: 'pie3d',
            angleField: 'Amount',
            donut: 30,
            distortion: 0.6,
            highlight: {
                margin: 40
            },
            label: {
                field: 'Summary',
                font: '22px sans-serif'
            },
            tooltip: {
                trackMouse: true,
                renderer: 'onTooltipRender'
            }
        }]
    }, {
        xtype: 'fieldset',
        title: '数据详情',
        collapsible: true,
        collapsed: false,
        scrollable: true,
        responsiveCls: 'big-100 small-100',
        items: [{
            xtype: 'grid',
            reference:'detail',
            store: {
                pageSize: 10000,
                data: [],
                autoLoad: false
            },
            columns: {
                defaults: {
                    menuDisabled: true,
                    sortable: false
                },
                items: [{
                        xtype: 'rownumberer'
                    }, {
                        dataIndex: 'Summary',
                        text: '类型',
                        minWidth: 230,
                        flex:1
                    },
                    {
                        dataIndex: 'Amount',
                        text: '已结算金额',
                        width: 120,
                        align: 'right'
                    }
                ]
            }
        }]
    }],
    listeners: {
        boxready: '_viewReady'
    },
    controller: {
        _requestData: function(_beginTime, _endTime, _ownerKvid) {
            let _controller = this;
            let _view = _controller.getView();
            let _refs = _view.getReferences();
            let _store = _refs.chart.getStore();
            _store.removeAll();
            let _detailStore=_refs.detail.getStore();
            _detailStore.removeAll();
            Ext.Ajax.request({
                url: '/Restful/Kivii.Finances.Entities.Settlement/PayedAnalysis.json',
                params: {
                    OwnerKvid: _ownerKvid,
                    Type: 'Type',
                    BeginTime: _beginTime, //new Date(new Date().getFullYear(), new Date().getMonth(), 1),
                    EndTime: _endTime //new Date(new Date().getFullYear(), new Date().getMonth(), new Date().getDate() + 1)
                },
                success: function(_response) {
                    let _rtns = Ext.decode(_response.responseText);
                    if(!_rtns||!_rtns.Results)return;
                    for (let _i = 0; _i < _rtns.Results.length; _i++) {
                        _store.add(_rtns.Results[_i]);
                        _detailStore.add(_rtns.Results[_i]);
                    }
                },
                failure: function(_response) {}
            });
        },
        _viewReady: function(_this, _eOpts) {
            let _controller = this;
            let _view = _controller.getView();
            let _refs = _view.getReferences();
            let _store = _refs.chart.getStore();
            let _beginTime = _refs.beginTime.value;
            let _endTime = _refs.endTime.value || new Date();
            _controller._requestData(_beginTime, _endTime, KiviiContext.CurrentMember.DepartmentKvid);
        },
        _onSelect: function(_ctrl, _record, _eOpts) {
            let _controller = this;
            let _view = _controller.getView();
            let _refs = _controller.getReferences();
            let _beginTime = _refs.beginTime.value;
            let _endTime = _refs.endTime.value || new Date();
            let _ownerKvid = _record.data.Kvid;
            if (_beginTime === null) {
                Ext.toast("请选择开始时间!");
                return;
            }
            if (_beginTime > _endTime) {
                Ext.toast("开始日期不能大于结束日期!");
                return;
            }
            _controller._requestData(_beginTime, _endTime, _ownerKvid);
        },
        _onSelectMonth: function(_ctrl, _time, _eOpts) {
            let _controller = this;
            let _view = _controller.getView();
            let _refs = _controller.getReferences();
            let _beginTime = _refs.beginTime.value;
            let _endTime = _refs.endTime.value || new Date();
            let _ownerKvid = _refs.depart.key;
            if (_beginTime === null) {
                Ext.toast("请选择开始时间!");
                return;
            }
            if (_beginTime > _endTime) {
                Ext.toast("开始日期不能大于结束日期!");
                return;
            }
            _controller._requestData(_beginTime, _endTime, _ownerKvid);
        },
        onTooltipRender: function(tooltip, record, item) {
            tooltip.setHtml(record.get('Summary') + ': ' +
                Ext.util.Format.number(record.get(item.field), '0,000 (元)'));
        },
    }

});