﻿using Kivii.DataAnnotations;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Kivii.Finances.Entities
{
    [Api(Description = "折扣,实收款项少于应收款项时用,例如应收1100,实际客户支付了1000,剩余100 需要使用此对象记录下来")]
    [Alias(Configs.TableNameDiscount)]
    public class Discount:EntityWithMetadata,IEntityInAssemblyDb,
        IEntityHasSummary,IEntityHasRemark,
        IEntityHasCreator
    {
        #region 关联信息 
        /// <summary>
        /// 所属部门
        /// </summary>
        [InternalSetter]
        [DefaultEmptyGuid]
        public Guid OwnerKvid { get; set; }

        [InternalSetter]
        [StringLength(500)]
        public string OwnerName { get; set; }

        [InternalSetter]
        [DefaultEmptyGuid]
        public Guid PayKvid { get; set; }

        #endregion

        #region 基本信息
        [ApiMember(Description = "流水号")]
        [IgnoreUpdate]
        [StringLength(100), Default(""), SerialNumber]
        public string SerialNumber { get; set; }

        /// <summary>
        /// 记录从哪个账户上折扣的
        /// </summary>
        [ApiMember(Description = "账户Kvid,记录从哪个账户上折扣的")]
        [IgnoreUpdate]
        [DefaultEmptyGuid]
        public Guid AccountKvid { get; set; }

        [ApiMember(Description = "账户名称,记录从哪个账户上折扣的")]
        [IgnoreUpdate]
        [StringLength(200), Default("")]
        public string AccountName { get; set; }

        [ApiMember(Description = "账户流水号")]
        [IgnoreUpdate]
        [StringLength(100), Default("")]
        public string AccountSerialNumber { get; set; }
        #endregion

        #region 费用相关

        [ApiMember(Description = "发生金额,抵扣的金额数")]
        [InternalSetter]
        [DecimalLength(15, 2), Default(0)]
        public decimal Amount { get; set; }

        [ApiMember(Description = "单位")]
        [IgnoreUpdate]
        [StringLength(50), Required]
        public CurrencyUnit Currency { get; set; }
        #endregion

        #region 文本 摘要 备注
        [ApiMember(Description = "摘要，最大500字")]
        [IgnoreUpdate]
        [StringLength(500), Default("")]
        public string Summary { get; set; }

        [ApiMember(Description = "备注，最大2000字")]
        [StringLength(2000), Default("")]
        public string Remark { get; set; }
        #endregion

        #region 操作相关  Organization Creator Updater Operator OperateTime 

        [ApiMember(Description = "操作日期")]
        [IgnoreUpdate]
        [Required]
        public DateTime OperateTime { get; set; }

        [IgnoreUpdate]
        [DefaultEmptyGuid]
        public Guid OperatorKvid { get; set; }

        [ApiMember(Description = "经办人")]
        [IgnoreUpdate]
        [StringLength(100), Default("")]
        public string OperatorName { get; set; }

        [ApiMember(Description = "组织机构Id,当组织有子组织时区分所属组织")]
        [IgnoreUpdate]
        [CurrentOrganizationKvid]
        public Guid OrganizationKvid { get; set; }

        [ApiMember(Description = "创建人Kvid")]
        [IgnoreUpdate]
        [CurrentMemberKvid]
        public Guid CreatorKvid { get; set; }

        [ApiMember(Description = "创建人")]
        [IgnoreUpdate]
        [StringLength(50), CurrentMemberName]
        public string CreatorName { get; set; }
        #endregion
    }
}
